# -*- coding: utf-8 -*-

# Copyright (C) 2004-2005 Johan Svedberg <johan@svedberg.com>

# This file is part of ontv.

# ontv is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# ontv is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with ontv; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import datetime
import os.path

import gtk.gdk

class Channel:
    def __init__(self, channel, logos_dir):
        self.id = channel["id"]
        self.display_name = channel["display-name"][0][0]
        logo_pixbuf = self.__get_logo_pixbuf(logos_dir)
        self.logo = self.__get_logo(logo_pixbuf)
        self.logo_small = self.__get_logo(logo_pixbuf, True)
        self.programs = []

    def __cmp__(self, other):
        return cmp(self.display_name, other.display_name)

    def __str__(self):
        return self.name

    def __get_logo(self, logo_pixbuf, logo_small=False):
        if logo_pixbuf:
            if not logo_small:
                return logo_pixbuf.scale_simple(48, 48, gtk.gdk.INTERP_BILINEAR)
            else:
                return logo_pixbuf.scale_simple(24, 24, gtk.gdk.INTERP_BILINEAR)
        else:
            return None

    def __get_logo_pixbuf(self, logos_dir):
        logo_file = os.path.join(logos_dir, self.display_name + ".png")
        if os.path.exists(logo_file):
            return gtk.gdk.pixbuf_new_from_file(logo_file)
        logo_file = os.path.join(logos_dir, self.display_name + ".jpg")
        if os.path.exists(logo_file):
            return gtk.gdk.pixbuf_new_from_file(logo_file)
        logo_file = os.path.join(logos_dir, self.display_name + ".gif")
        if os.path.exists(logo_file):
            return gtk.gdk.pixbuf_new_from_file(logo_file)
        return None

    def get_current_program(self):
        for program in self.programs:
            if program.time_span.spans_now():
                return program
        return None

    def get_upcoming_program(self):
        for program in self.programs:
            if program.time_span.start > datetime.datetime.now():
                return program
        return None

# vim: set sw=4 et sts=4 tw=79 fo+=l:
