# -*- coding: utf-8 -*-

# Copyright (C) 2004-2005 Johan Svedberg <johan@svedberg.com>

# This file is part of ontv.

# ontv is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# ontv is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with ontv; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gettext
import locale
import os.path
import sys
import thread
from gettext import gettext as _

import pygtk
pygtk.require("2.0")
import gtk
import gnome
import gnomeapplet
import gobject

from Configuration import Configuration
from Listings import Listings
from XMLTVFile import XMLTVFile
from ProgramWindow import ProgramWindow
from ToggleButton import ToggleButton
from PreferencesDialog import PreferencesDialog
from AboutDialog import AboutDialog
from ontv import NAME, VERSION, UI_DIR, LOCALE_DIR

gettext.bindtextdomain(NAME.lower(), LOCALE_DIR)
gettext.textdomain(NAME.lower())

locale.bindtextdomain(NAME.lower(), LOCALE_DIR)
locale.textdomain(NAME.lower())

class OnTVApplet(gnomeapplet.Applet):
    def __init__(self, applet):
        self.__gobject_init__()
        self.applet = applet

        self.config = Configuration()
        self.listings = Listings()
        self.xmltvfile = XMLTVFile(self.listings, self.config)

        self.pw = ProgramWindow(self.config, self.listings)
        self.tb = ToggleButton(self.pw)
        self.pd = PreferencesDialog(self)

        ui_file = os.path.join(UI_DIR, "GNOME_OnTVApplet.xml")
        verb_list = [("Reload XMLTV file", self.reload_xmltvfile_in_thread),
                     ("Preferences", self.pd.show), ("About", self.__run_ad)]
        self.applet.setup_menu_from_file(None, ui_file, NAME, verb_list)

        self.applet.add(self.tb)

        self.auto_reload = {}

        self.applet.show_all()

    def reload_xmltvfile_in_thread(self, uicomponent=None, verb=None):
        thread.start_new_thread(self.reload_xmltvfile, ())

    def reload_xmltvfile(self):
        self.tb.set_tooltip(_("Loading XMLTV file..."))
        self.xmltvfile.reload()
        gtk.threads_enter()
        self.pw.update()
        self.pd.update_xmltv_data()
        self.pd.update_channels_treeview()
        gtk.threads_leave()
        self.tb.set_tooltip(None)

    def __run_ad(self, uicomponent=None, verb=None):
        self.ad = AboutDialog()
        self.ad.run()

    def start_auto_reload(self, rate):
        if rate >= 1:
            timeout = rate * 3600 * 1000
            self.auto_reload["id"] = gobject.timeout_add(timeout, self.reload_xmltvfile_in_thread)
            self.auto_reload["rate"] = rate
            if self.config.debug:
                print("[Added timeout %s]: %sh" % (str(self.auto_reload["id"]), str(rate)))

    def stop_auto_reload(self):
        if self.auto_reload.has_key("id"):
            gobject.source_remove(self.auto_reload["id"])
            if self.config.debug:
                print("[Removed timeout %s]: %sh" % (str(self.auto_reload["id"]), str(self.auto_reload["rate"])))

    def run(self):
        if self.config.xmltv_file == '':
            self.pd.show()
            self.pd.notebook.set_current_page(0)
        else:
            self.xmltvfile.path = self.config.xmltv_file
            if self.config.auto_reload_xmltv_file:
                self.start_auto_reload(self.config.auto_reload_xmltv_file_rate)
            self.reload_xmltvfile_in_thread()

def main():
    gobject.type_register(OnTVApplet)
    if len(sys.argv) > 1 and sys.argv[1] == "run-in-window":
        main_window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        main_window.set_title(NAME)
        main_window.connect("destroy", gtk.main_quit)
        gnome.init(NAME, VERSION)
        applet = gnomeapplet.Applet()
        applet_factory(applet)
        applet.reparent(main_window)
        main_window.show_all()
        gtk.threads_init()
        gtk.main()
    else:
        activate_factory()

def applet_factory(applet, iid=None):
    gtk.threads_init()
    ontvapplet = OnTVApplet(applet)
    ontvapplet.run()
    return True

def activate_factory():
    gnomeapplet.bonobo_factory("OAFIID:GNOME_OnTVApplet_Factory",
                                OnTVApplet.__gtype__, NAME, VERSION,
                                applet_factory)

# vim: set sw=4 et sts=4 tw=79 fo+=l:
