# -*- coding: utf-8 -*-

# Copyright (C) 2004-2005 Johan Svedberg <johan@svedberg.com>

# This file is part of ontv.

# ontv is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# ontv is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with ontv; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import datetime
import re

from TimeSpan import TimeSpan

class Program:
    def __init__(self, program, channel):
        self.program = program
        self.title = self.program["title"][0][0]
        self.channel = channel
        self.description = self.__get_description()
        self.start = self.__get_datetime("start")
        self.stop = self.__get_datetime("stop")
        self.time_span = TimeSpan(self.start, self.stop)

    def __cmp__(self, other):
        return cmp(self.time_span.start, other.time_span.start)

    def __str__(self):
        return self.title

    def __get_description(self):
        if self.program.has_key("desc"):
            return self.program["desc"][0][0]
        else:
            return None

    def __get_datetime(self, time):
        if self.program.has_key(time):
            time_re = re.compile(r"(\d{4})(\d\d)(\d\d)(\d\d)(\d\d)")
            match = time_re.match(self.program[time])
            ints = [int(x) for x in match.groups()]
            return datetime.datetime(*ints)
        else:
            return None

    def get_time_until_start(self):
        return self.time_span.time_until_start()

    def get_time_until_stop(self):
        return self.time_span.time_until_stop()

# vim: set sw=4 et sts=4 tw=79 fo+=l:
