# -*- coding: utf-8 -*-

# Copyright (C) 2004-2005 Johan Svedberg <johan@svedberg.com>

# This file is part of ontv.

# ontv is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# ontv is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with ontv; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os.path
from gettext import gettext as _

import gtk

import xmltv
from GUI import ErrorDialog
from Channel import Channel
from Program import Program

class XMLTVFile:
    def __init__(self, listings, config):
        self.listings = listings
        self.config = config
        self.path = None
        self.data = {}
        self.channel_names = {}

    def reload(self):
        error_msg = ""
        try:
            self.data = self.__get_data()
            self.__get_channels()
            self.__get_programs()

            for channel in self.listings.values():
                channel.programs.sort()

            return
        except IOError, ioe:
            if ioe.errno == 2:
                error_msg = _("File not found")
            elif ioe.errno == 13:
                error_msg = _("Access denied")
            else:
                error_msg = _("Unknown error")

        gtk.threads_enter()
        ed = ErrorDialog(_("Failed to load ") + self.path, error_msg)
        ed.run()
        ed.destroy()
        gtk.threads_leave()

    def __get_data(self):
        return xmltv.read_data(open(self.path))

    def __get_channels(self):
        logos_dir = os.path.join(self.config.base_dir, "logos")
        for channel in xmltv.read_channels(open(self.path)):
            channel_object = Channel(channel, logos_dir)
            self.channel_names[channel_object.id] = channel_object.display_name
            self.listings.add_channel(channel_object)

    def __get_programs(self):
        for program in xmltv.read_programmes(open(self.path)):
            channel = self.__get_channel_name(program)
            self.listings.add_program(Program(program, channel))

    def __get_channel_name(self, program):
        return self.channel_names[program["channel"]]

# vim: set sw=4 et sts=4 tw=79 fo+=l:
